<?php

App::uses('EvShopAppController', 'EvShop.Controller');

class CategoryOverridesController extends EvShopAppController {

/**
 * Used to populate form drop down selects.
 *
 * @return void.
 */
	protected function _adminPopulateLookups() {
		$Model = $this->{$this->modelClass};

		$this->set(
			'categories',
			$Model->Category->generateTreeList(
				null,
				null,
				null,
				'--'
			)
		);

		$this->set(
			'brands',
			$Model->Brand->find('list')
		);
	}

/**
 * Defines the buttons in the toolbar displayed on an admin_index page.
 *
 * @return array
 */
	protected function _adminIndexToolbar() {
		$Model = $this->{$this->modelClass};
		$modelAlias = $Model->alias;

		$actions = parent::_adminIndexToolbar();

		$actions['Back To Categories'] = [
			'url' => [
				'plugin' => 'ev_shop',
				'controller' => 'categories',
				'action' => 'index',
			],
			'class' => 'toolbar__btn toolbar__btn--listing'
		];

		return $actions;
	}

/**
 * Pagination settings for admin_index.
 *
 * @return array Pagination settings.
 */
	protected function _adminIndexPaginate() {
		$Model = $this->{$this->modelClass};

		$paginate = parent::_adminIndexPaginate();

		$paginate['contain']['Brand'] = [];

		$paginate['joins'][] = [
			'type' => 'left',
			'table' => 'ev_shop_category_overrides_options',
			'alias' => 'CategoryOverridesOption',
			'conditions' => [
				'CategoryOverridesOption.category_override_id = ' . $Model->alias . '.id',
			],
		];

		$paginate['joins'][] = [
			'type' => 'left',
			'table' => 'ev_shop_options',
			'alias' => 'Option',
			'conditions' => [
				'Option.id = CategoryOverridesOption.option_id',
			],
		];

		$Model->virtualFields['options'] = 'GROUP_CONCAT(Option.name)';

		return $paginate;
	}

/**
 * Defines the columns displayed in the admin_index results table using a columns whitelist.
 *
 * @return array Index columns
 */
	protected function _adminIndexColumns() {
		$alias = $this->{$this->modelClass}->alias;

		$columns = parent::_adminIndexColumns();

		$additionalColumns = [
			'Brand.name' => [
				'type' => 'string',
				'label' => 'Brand',
			],
			$alias . '.options' => [
				'type' => 'string',
				'label' => 'Options'
			],
		];

		$columns = ArrayUtil::addBefore($columns, $alias . '.created', $additionalColumns);

		return $columns;
	}

/**
 * Defines the buttons in the toolbar displayed on an admin_edit page.
 *
 * @param int $id The id of the record being edited.
 * @return array
 */
	protected function _adminFormToolbar($id = null) {
		$Model = $this->{$this->modelClass};
		$modelAlias = $Model->alias;

		$actions = parent::_adminFormToolbar($id);

		$actions['Back To Overrides'] = [
			'url' => [
				'plugin' => 'ev_shop',
				'controller' => 'category_overrides',
				'action' => 'index',
			],
			'class' => 'toolbar__btn toolbar__btn--listing'
		];

		return $actions;
	}

/**
 * Defines the fields displayed in an admin_form for this model. Defaults to all fields in the db table.
 *
 * @return array Form fields.
 */
	protected function _adminFormFields() {
		$Model = $this->{$this->modelClass};
		$alias = $Model->alias;

		$fields = parent::_adminFormFields();

		if (isset($fields[$alias . '.override_hash'])) {
			unset($fields[$alias . '.override_hash']);
		}

		$optionGroups = $Model->Option->OptionGroup->find('all', ['contain' => 'Option']);

		foreach ($optionGroups as $group) {
			if (!empty($group['Option'])) {
				$fields['tabs']['Options']['Option.' . $group['OptionGroup']['id']] = [
					'type' => 'select',
					'options' => Hash::combine($group['Option'], '{n}.id', '{n}.name'),
					'label' => $group['OptionGroup']['name'],
				];
			}
		}

		return $fields;
	}
}
